pub fn build_function_doc(func: &dyn Function) -> FunctionDocExpand description
Panics
Will panic if any function’s example has an input that is not valid JSON
pub fn build_function_doc(func: &dyn Function) -> FunctionDocWill panic if any function’s example has an input that is not valid JSON